@@ -27,6 +27,7 @@ EXTENSIONS = {
     'cpp': {'text', 'c++'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
+    'csproj': {'text', 'xml', 'csproj'},
     'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
@@ -151,6 +152,7 @@ EXTENSIONS = {
     'scm': {'text', 'scheme'},
     'scss': {'text', 'scss'},
     'sh': {'text', 'shell'},
+    'sln': {'text', 'sln'},
     'sls': {'text', 'salt'},
     'so': {'binary'},
     'sol': {'text', 'solidity'},
@@ -176,6 +178,7 @@ EXTENSIONS = {
     'ts': {'text', 'ts'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
+    'twig': {'text', 'twig'},
     'txsprofile': {'text', 'ini', 'txsprofile'},
     'txt': {'text', 'plain-text'},
     'v': {'text', 'verilog'},
